==> nextcloud-24.0.12.tgz: nextcloud/apps/comments/l10n/vi.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Các bình luận",
    "You commented" : "Bạn đã bình luận",
    "{author} commented" : "{author} đã bình luận",
    "You commented on %1$s" : "Bạn đã bình luận về %1$s",
    "You commented on {file}" : "Bạn đã bình luận đối với tệp tin {file}",
    "%1$s commented on %2$s" : "%1$s đã bình luận về%2$s",
    "{author} commented on {file}" : "{author} đã bình luận về tệp tin {file}",
    "<strong>Comments</strong> for files" : "<strong>bình luận</strong> đối với các tệp tin",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Bạn đã được nhắc tới trên \"{file}\", trong một bình luận bởi một người dùng đã bị xoá",
    "{user} mentioned you in a comment on \"{file}\"" : "{user}  đã nhắc tới bạn trong một bình luận trên \"{file}\"",
    "Files app plugin to add comments to files" : "Plugin ứng dụng Tệp để thêm bình luận vào tệp",
    "Edit comment" : "Sửa bình luận",
    "Delete comment" : "Xóa bình luận",
    "Cancel edit" : "Hủy chỉnh sửa",
    "Post comment" : "Đăng bình luận",
    "No comments yet, start the conversation!" : "Không có bình luận nào, bắt đầu cuộc hội thoại!",
    "No more messages" : "Không có thêm tin nhắn",
    "Retry" : "Thử lại",
    "Unable to load the comments list" : "Không thể tải danh sách bình luận",
    "_%n unread comment_::_%n unread comments_" : ["%n bình luận chưa đọc"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} bình luận mới"],
    "Comment" : "Bình luận",
    "An error occurred while trying to edit the comment" : "Đã xảy ra lỗi khi cố gắng chỉnh sửa bình luận",
    "Comment deleted" : "Đã xóa bình luận",
    "An error occurred while trying to delete the comment" : "Đã xảy ra lỗi khi cố gắng xóa bình luận",
    "An error occurred while trying to create the comment" : "Đã xảy ra lỗi khi cố gắng tạo bình luận",
    "%1$s commented" : "%1$s được bình luận"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.11.tgz: nextcloud/apps/comments/l10n/vi.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Bình luận",
    "You commented" : "Bạn đã bình luận",
    "{author} commented" : "{author} đã bình luận",
    "You commented on %1$s" : "Bạn đã bình luận về %1$s",
    "You commented on {file}" : "Bạn đã bình luận đối với tệp tin {file}",
    "%1$s commented on %2$s" : "%1$s đã bình luận về%2$s",
    "{author} commented on {file}" : "{author} đã bình luận về tệp tin {file}",
    "<strong>Comments</strong> for files" : "<strong>bình luận</strong> đối với các tệp tin",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Bạn đã được nhắc tới trên \"{file}\", trong một bình luận bởi một người dùng đã bị xoá",
    "{user} mentioned you in a comment on \"{file}\"" : "{user}  đã nhắc tới bạn trong một bình luận trên \"{file}\"",
    "Files app plugin to add comments to files" : "Plugin ứng dụng Tệp để thêm bình luận vào tệp",
    "Edit comment" : "Sửa bình luận",
    "Delete comment" : "Xóa bình luận",
    "Cancel edit" : "Hủy chỉnh sửa",
    "Post comment" : "Đăng bình luận",
    "No comments yet, start the conversation!" : "Không có bình luận nào, bắt đầu cuộc hội thoại!",
    "No more messages" : "Không có thêm tin nhắn",
    "Retry" : "Thử lại",
    "Failed to mark comments as read" : "Không thể đánh dấu bình luận là đã đọc",
    "Unable to load the comments list" : "Không thể tải danh sách bình luận",
    "_%n unread comment_::_%n unread comments_" : ["%n bình luận chưa đọc"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} bình luận mới"],
    "Comment" : "Bình luận",
    "An error occurred while trying to edit the comment" : "Đã xảy ra lỗi khi cố gắng chỉnh sửa bình luận",
    "Comment deleted" : "Đã xóa bình luận",
    "An error occurred while trying to delete the comment" : "Đã xảy ra lỗi khi cố gắng xóa bình luận",
    "An error occurred while trying to create the comment" : "Đã xảy ra lỗi khi cố gắng tạo bình luận",
    "%1$s commented" : "%1$s được bình luận"
},
"nplurals=1; plural=0;");
